@@ -20,5 +20,5 @@ from os import path
 from .color_format import ColorFormat
 from .color import HexRGB
 
-DEFAULT_PALETTES_DIR = path.join(path.dirname(path.dirname(__file__)), "../palettes")
+DEFAULT_PALETTES_DIR = path.join(path.dirname(path.dirname(__file__)), "palettes")
 DEFAULT_COLOR_FORMAT = ColorFormat(HexRGB)
\ No newline at end of file
