@@ -7,12 +7,12 @@ Examples:
 
     >>> grad = RGBLinearGrad([sRGB(255, 0, 0), sRGB(0, 0, 255), sRGB(255, 255, 255)])
     >>> grad.perc(0.25)
-    sRGB(127.5, 0.0, 127.5)
+    HexRGB(#7f007f)
 
     Get 3 colors interspaced in the gradient:
 
     >>> grad.n_colors(3)
-    [sRGB(127.5, 0.0, 127.5), sRGB(0.0, 0.0, 255.0), sRGB(127.5, 127.5, 255.0)]
+    [HexRGB(#7f007f), HexRGB(#0000ff), HexRGB(#7f7fff)]
 """
 from typing import Iterable
 from math import pow
@@ -41,10 +41,7 @@ class RGBLinearGrad:
     def __init__(self, colors: Iterable[ColorBase], color_format=None, use_linear_RGB=False):
         colors = list(colors)
         if color_format is None:
-            if colors and isinstance(colors[0], ColorBase):
-                color_format = colors[0].get_format()
-            else:
-                color_format = config.DEFAULT_COLOR_FORMAT
+            color_format = config.DEFAULT_COLOR_FORMAT
         self.color_format = color_format
         self.colors = [self.color_format.format(color) for color in colors]
         self.use_linear_RGB = use_linear_RGB
@@ -61,12 +58,12 @@ class RGBLinearGrad:
 
             >>> grad = RGBLinearGrad([sRGB(255, 0, 0), sRGB(0, 0, 255)])
             >>> grad.perc(0.5)
-            sRGB(127.5, 0.0, 127.5)
+            HexRGB(#7f007f)
 
             Get a very "reddish" purple:
 
             >>> grad.perc(0.2)
-            sRGB(204.0, 0.0, 51.0)
+            HexRGB(#cc0033)
         """
 
         i = int(p * (len(self.colors) - 1))
